@@ -68,13 +68,22 @@ class CVise:
             try:
                 pass_group_dict = json.load(pass_group_file)
             except json.JSONDecodeError:
-                raise CViseError('Not valid JSON.')
+                raise CViseError('Not valid JSON.') from None
 
         return pass_group_dict
 
     @classmethod
-    def parse_pass_group_dict(cls, pass_group_dict, pass_options, external_programs, remove_pass,
-                              clang_delta_std, clang_delta_preserve_routine, not_c, renaming):
+    def parse_pass_group_dict(
+        cls,
+        pass_group_dict,
+        pass_options,
+        external_programs,
+        remove_pass,
+        clang_delta_std,
+        clang_delta_preserve_routine,
+        not_c,
+        renaming,
+    ):
         pass_group = {}
         removed_passes = set(remove_pass.split(',')) if remove_pass else set()
 
@@ -85,13 +94,14 @@ class CVise:
                 try:
                     valid_options.add(AbstractPass.Option(opt))
                 except ValueError:
-                    raise PassOptionError(opt)
+                    raise PassOptionError(opt) from None
 
             return valid_options
 
         def include_pass(pass_dict, options):
-            return ((('include' not in pass_dict) or bool(parse_options(pass_dict['include']) & options)) and
-                    (('exclude' not in pass_dict) or not bool(parse_options(pass_dict['exclude']) & options)))
+            return (('include' not in pass_dict) or bool(parse_options(pass_dict['include']) & options)) and (
+                ('exclude' not in pass_dict) or not bool(parse_options(pass_dict['exclude']) & options)
+            )
 
         for category in ['first', 'main', 'last']:
             if category not in pass_group_dict:
@@ -109,7 +119,7 @@ class CVise:
                 try:
                     pass_class = cls.pass_name_mapping[pass_dict['pass']]
                 except KeyError:
-                    raise CViseError('Unkown pass {}'.format(pass_dict['pass']))
+                    raise CViseError('Unkown pass {}'.format(pass_dict['pass'])) from None
 
                 pass_instance = pass_class(pass_dict.get('arg'), external_programs)
                 pass_instance.max_transforms = None
@@ -138,8 +148,12 @@ class CVise:
             self.test_manager.check_sanity(True)
 
         logging.info(f'===< {os.getpid()} >===')
-        logging.info('running {} interestingness test{} in parallel'.format(self.test_manager.parallel_tests,
-                                                                            '' if self.test_manager.parallel_tests == 1 else 's'))
+        logging.info(
+            'running {} interestingness test{} in parallel'.format(
+                self.test_manager.parallel_tests,
+                '' if self.test_manager.parallel_tests == 1 else 's',
+            )
+        )
 
         if not self.tidy:
             self.test_manager.backup_test_cases()
